@@ -1,16 +1,20 @@
 from logging import getLogger
+from typing import Iterable
 
 from pymongo import MongoClient
 from pymongo.errors import DuplicateKeyError
 
 from monutils.db import connect
-from dbtqdm.mongo import tqdm
 
 from monutils.args import CopyArgParser
 
 logger = getLogger(__name__)
 
 
+def dummy_tqdm(iterable: Iterable, *_, **kwargs) -> Iterable:
+    return iterable
+
+
 def copy(from_client: MongoClient, to_client: MongoClient, from_database: str, to_database: str,
          from_collection: str, to_collection: str, ignore_errors: bool = False) -> None:
     """ Copy a MongoDB collection to another.
@@ -23,6 +27,12 @@ def copy(from_client: MongoClient, to_client: MongoClient, from_database: str, t
     :param to_collection: The target collection.
     :param ignore_errors: If activate, ignore copy errors.
     """
+    try:
+        from dbtqdm.mongo import tqdm
+    except ImportError:
+        logger.warning('db-tqdm is not installed. If you want a progress bar, please install db-tqdm:\n\n'
+                       'pip install db-tqdm>=1.1.3,<2.0')
+        tqdm = dummy_tqdm
     from_collection = from_client[from_database][from_collection]
     to_collection = to_client[to_database][to_collection]
     total = from_collection.count_documents({})
